@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Parameter::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Parameter::VERSION    = '2.007_003';
+	$Type::Params::Parameter::VERSION    = '2.007_004';
 }
 
 $Type::Params::Parameter::VERSION =~ tr/_//d;
@@ -84,7 +84,8 @@ sub might_supply_new_value {
 
 sub _all_aliases {
 	my ( $self, $signature ) = @_;
-	my $allow_dash = $self->{allow_dash} // $signature->allow_dash;
+	my $allow_dash = $self->{allow_dash};
+	$allow_dash = $signature->allow_dash if !defined $allow_dash;
 	my @aliases;
 	if ( $allow_dash and $self->name =~ $RE_WORDLIKE ) {
 		push @aliases, sprintf( '-%s', $self->name );
